Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(759)

Unified Diff: webrtc/p2p/base/session.h

Issue 1269843005: Added DtlsCertificate, a ref counted object owning an SSLIdentity (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Merge with master Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/p2p/base/session.h
diff --git a/webrtc/p2p/base/session.h b/webrtc/p2p/base/session.h
index 19ce3611b077b697990d2a932855bcaefe5852c1..ceeef7af6b276cba5d118cbb7b677dd19cb24f4d 100644
--- a/webrtc/p2p/base/session.h
+++ b/webrtc/p2p/base/session.h
@@ -100,7 +100,8 @@ class TransportProxy : public sigslot::has_slots<> {
// Simple functions that thunk down to the same functions on Transport.
void SetIceRole(IceRole role);
- void SetIdentity(rtc::SSLIdentity* identity);
+ void SetCertificate(
+ const rtc::scoped_refptr<webrtc::DtlsCertificate>& certificate);
bool SetLocalTransportDescription(const TransportDescription& description,
ContentAction action,
std::string* error_desc);
@@ -317,14 +318,17 @@ class BaseSession : public sigslot::has_slots<>,
virtual void DestroyChannel(const std::string& content_name,
int component);
- rtc::SSLIdentity* identity() { return identity_; }
+ const rtc::scoped_refptr<webrtc::DtlsCertificate>& certificate() {
+ return certificate_;
+ }
// Set the ice connection receiving timeout.
void SetIceConnectionReceivingTimeout(int timeout_ms);
protected:
- // Specifies the identity to use in this session.
- bool SetIdentity(rtc::SSLIdentity* identity);
+ // Specifies the certificate to use in this session.
+ bool SetCertificate(
+ const rtc::scoped_refptr<webrtc::DtlsCertificate>& certificate);
bool SetSslMaxProtocolVersion(rtc::SSLProtocolVersion version);
@@ -447,7 +451,7 @@ class BaseSession : public sigslot::has_slots<>,
const std::string content_type_;
const std::string transport_type_;
bool initiator_;
- rtc::SSLIdentity* identity_;
+ rtc::scoped_refptr<webrtc::DtlsCertificate> certificate_;
rtc::SSLProtocolVersion ssl_max_version_;
rtc::scoped_ptr<const SessionDescription> local_description_;
rtc::scoped_ptr<SessionDescription> remote_description_;

Powered by Google App Engine
This is Rietveld 408576698